@@ -1,16 +1,21 @@
 # Author: Prabhu Ramachandran, Gael Varoquaux
-# Copyright (c) 2004-2016, Enthought, Inc.
+# Copyright (c) 2004-2018, Enthought, Inc.
 # License: BSD Style.
 """ A tool for easy and interactive visualization of data.
     Part of the Mayavi project of the Enthought Tool Suite.
 """
 
-__version__ = '4.5.0'
+__version__ = '4.6.0'
 
 __requires__ = [
     'apptools',
-    'traits',
-    'traitsui',
+    'envisage',
+    'numpy',
+    'pyface>=6.0.0',
+    'pygments',  # This is only needed for the Qt backend but we add it anyway.
+    'traits>=4.6.0',
+    'traitsui>=6.0.0',
+    'vtk'
 ]
 
 __extras_require__ = {
@@ -20,19 +25,6 @@ __extras_require__ = {
 }
 
 
-# Try forcing the use of wx 2.8 before any other import.
-import sys
-if not 'wx' in sys.modules:
-    try:
-        # Try forcing the use of wx 2.8
-        from traits.etsconfig.api import ETSConfig
-        if ETSConfig.toolkit in ('wx', ''):
-            import wxversion
-            wxversion.ensureMinimal('2.8')
-    except ImportError:
-        """ wxversion not installed """
-
-
 def _jupyter_nbextension_paths():
     return [dict(
         section="notebook",
@@ -40,4 +32,5 @@ def _jupyter_nbextension_paths():
         src="tools/static",
         # directory in the `nbextension/` namespace
         dest="mayavi",
+        require="mayavi/x3d/x3dom"
     )]
